import React from "react";
import PropTypes from "prop-types";
import { makeStyles } from "@material-ui/core/styles";
import Timeline from "@material-ui/lab/Timeline";
import TimelineItem from "@material-ui/lab/TimelineItem";
import TimelineSeparator from "@material-ui/lab/TimelineSeparator";
import TimelineConnector from "@material-ui/lab/TimelineConnector";
import TimelineContent from "@material-ui/lab/TimelineContent";
import TimelineOppositeContent from "@material-ui/lab/TimelineOppositeContent";
import TimelineDot from "@material-ui/lab/TimelineDot";
import Paper from "@material-ui/core/Paper";
import Typography from "@material-ui/core/Typography";
import { useTranslation } from "react-i18next";
import { getRandomElement } from "../../../utils";
import {
  Announcement,
  AmpStories,
  Apps,
  BugReport,
  DeviceHub,
  Equalizer,
  FilterTiltShift,
  Grain,
  Layers,
  LocalOffer,
  Memory,
  NetworkCheck,
  OfflineBolt,
  Star,
  Whatshot,
  Widgets
} from "@material-ui/icons";

const timelineIcons = [
  Announcement,
  AmpStories,
  Apps,
  BugReport,
  DeviceHub,
  Equalizer,
  FilterTiltShift,
  Grain,
  Layers,
  LocalOffer,
  Memory,
  NetworkCheck,
  OfflineBolt,
  Star,
  Whatshot,
  Widgets
];

const timelineDotVariants = [
  { color: "primary", variant: "outlined" },
  { color: "secondary", variant: "outlined" }
];

const useStyles = makeStyles(() => ({
  paper: {
    padding: "6px 16px"
  }
}));

const TimelineComponent = ({ releases }) => {
  const classes = useStyles();
  const { t } = useTranslation();

  const _releases = releases.map((release, index) => {
    const isLast = index === releases.length - 1;
    const icon = getRandomElement(timelineIcons);
    const dot = getRandomElement(timelineDotVariants);
    return { ...release, isLast, icon, dot };
  });

  return (
    <Timeline align="alternate">
      {_releases.map(release => (
        <TimelineItem key={release.version}>
          <TimelineOppositeContent>
            <Typography variant="body2" color="textSecondary">
              {t("DATE_FORMAT", {
                date: { value: release.date, format: "DD-MM-YYYY HH:mm" }
              })}
            </Typography>
          </TimelineOppositeContent>
          <TimelineSeparator>
            <TimelineDot
              color={release.dot.color}
              variant={release.dot.variant}
            >
              <release.icon />
            </TimelineDot>
            {!release.isLast && <TimelineConnector />}
          </TimelineSeparator>
          <TimelineContent>
            <Paper elevation={3} className={classes.paper}>
              <Typography variant="h6" component="h1">
                {release.notes[0]}
              </Typography>
              {release.notes.slice(1).map((note, index) => (
                <Typography key={index} variant="body2">
                  {note}
                </Typography>
              ))}
            </Paper>
          </TimelineContent>
        </TimelineItem>
      ))}
    </Timeline>
  );
};

TimelineComponent.propTypes = {
  releases: PropTypes.array.isRequired
};

export default TimelineComponent;
