import React from "react";
import PropTypes from "prop-types";
import {
  Accordion,
  AccordionSummary,
  AccordionDetails,
  Grid
} from "@material-ui/core";
import ExpandMoreIcon from "@material-ui/icons/ExpandMore";
import withStyles from "@material-ui/core/styles/withStyles";
import MachineLog from "./common/MachineLog";
import { DataLabel } from "../../../components/common";
import { useTranslation } from "react-i18next";
import { useSensitiveInfo } from "../../../hooks";
import ActionsGroup from "./common/ActionsGroup";
import { makeStyles } from "@material-ui/core/styles";

const useStyles = makeStyles(() => ({
  panel: {
    justifyContent: "center",
    alignItems: "center"
  }
}));

const IconLeftAccordionSummary = withStyles(theme => ({
  root: {
    minHeight: "20px",
    height: "42px",
    [theme.breakpoints.down("md")]: {
      height: "62px"
    },
    [theme.breakpoints.down("sm")]: {
      height: "102px"
    }
  },
  expandIcon: {
    order: -1
  }
}))(AccordionSummary);

const GridCell = ({ label, value }) => {
  const { mask } = useSensitiveInfo();
  return (
    <Grid item xs={12} md={6} lg={3}>
      <DataLabel label={label} data={mask(value)} />
    </Grid>
  );
};

GridCell.propTypes = {
  label: PropTypes.string.isRequired,
  value: PropTypes.string.isRequired
};

const MachineAccordion = ({ machine, actions, logs, addLog }) => {
  const { t } = useTranslation();
  const classes = useStyles();
  return (
    <Accordion>
      <IconLeftAccordionSummary
        expandIcon={<ExpandMoreIcon />}
        aria-label="Expand"
        aria-controls="additional-actions1-content"
        id="additional-actions1-header"
        IconButtonProps={{ edge: "start" }}
      >
        <Grid container className={classes.panel}>
          <Grid item xs={11}>
            <Grid container>
              <GridCell
                label={t("Machine.FullName")}
                value={machine.fullMachineName}
              />
              <GridCell label={t("Machine.Name")} value={machine.machineName} />
              <GridCell label={t("Machine.IP")} value={machine.iPv4Address} />
              <GridCell label={t("Machine.MAC")} value={machine.macAddress} />
            </Grid>
          </Grid>
          <Grid item xs={1} style={{ textAlign: "right" }}>
            <ActionsGroup
              className={classes.actions}
              machine={machine}
              actions={actions}
              addLog={addLog}
            />
          </Grid>
        </Grid>
      </IconLeftAccordionSummary>
      <AccordionDetails>
        <MachineLog logs={logs} />
      </AccordionDetails>
    </Accordion>
  );
};

MachineAccordion.propTypes = {
  machine: PropTypes.shape({
    machineId: PropTypes.number.isRequired,
    machineName: PropTypes.string.isRequired,
    fullMachineName: PropTypes.string.isRequired,
    macAddress: PropTypes.string.isRequired,
    iPv4Address: PropTypes.string,
    description: PropTypes.string
  }).isRequired,
  actions: PropTypes.array.isRequired,
  logs: PropTypes.array.isRequired,
  addLog: PropTypes.func.isRequired
};

export default MachineAccordion;
