import React from "react";
import PropTypes from "prop-types";
import { IconButton, Tooltip } from "@material-ui/core";

const ActionButton = React.forwardRef((props, _ref) => {
  const { action, machine, callback } = props;
  const id = `machine-item-${machine.machineId}-${action.code}`;
  const handleActionClick = event => {
    action.effect(machine, event);
    callback && callback(machine);
    event.stopPropagation();
  };

  return (
    <Tooltip
      id={`machine-item-${machine.machineId}-${action.code}-tooltip`}
      title={action.tooltip}
    >
      <span>
        <IconButton
          id={id}
          size={"small"}
          onFocus={event => event.stopPropagation()}
          onClick={handleActionClick}
        >
          <action.icon />
        </IconButton>
      </span>
    </Tooltip>
  );
});

ActionButton.propTypes = {
  machine: PropTypes.shape({
    machineId: PropTypes.number.isRequired
  }).isRequired,
  action: PropTypes.shape({
    code: PropTypes.string.isRequired,
    tooltip: PropTypes.string.isRequired,
    effect: PropTypes.func.isRequired
  }).isRequired,
  callback: PropTypes.func
};

export default ActionButton;
