import React, { useState, useMemo } from "react";
import BrushIcon from "@material-ui/icons/Brush";
import NotificationsIcon from "@material-ui/icons/Notifications";
import { useTranslation } from "react-i18next";
import PageTitle from "../../components/common/PageTitle";
import NavigationButtons from "../../components/common/NavigationButtons";
import AppearanceContainer from "./appearance/AppearanceContainer";
import NotificationsContainer from "./notifications/NotificationsContainer";

const NavigationTabs = {
  APPEARANCE: "Settings.Navigation.Appearance",
  NOTIFICATIONS: "Settings.Navigation.Notifications"
};

const tabs = [
  {
    code: NavigationTabs.APPEARANCE,
    icon: BrushIcon
  },
  {
    code: NavigationTabs.NOTIFICATIONS,
    icon: NotificationsIcon
  }
];

const SettingsContainer = () => {
  const [tab, setTab] = useState(NavigationTabs.APPEARANCE);
  const { t } = useTranslation();

  const navigationTabs = useMemo(
    () => tabs.map(z => ({ ...z, tooltip: t(z.code) })),
    [t]
  );

  return (
    <>
      <PageTitle
        text={t(tab)}
        navigation={
          <NavigationButtons tabs={navigationTabs} onTabChange={setTab} />
        }
      />
      {tab === NavigationTabs.APPEARANCE && <AppearanceContainer />}
      {tab === NavigationTabs.NOTIFICATIONS && <NotificationsContainer />}
    </>
  );
};

export default SettingsContainer;
