import React from "react";
import PropTypes from "prop-types";
import Flag from "react-flags";
import { IconButton, Menu, MenuItem } from "@material-ui/core";
import { useTranslation } from "react-i18next";

const LanguageComponent = ({
  languageIsSet,
  anchorEl,
  onMenuOpen,
  onLanguageChange,
  onClose,
  flag,
  flagsPath
}) => {
  const { t } = useTranslation();
  const open = Boolean(anchorEl);

  return (
    <>
      <IconButton
        aria-controls="language-menu"
        aria-haspopup="true"
        onClick={onMenuOpen}
        color="inherit"
        size="small"
      >
        {languageIsSet && (
          <Flag
            name={flag.name}
            format="png"
            pngSize={32}
            shiny={true}
            basePath={flagsPath}
            alt={flag.alt}
          />
        )}
      </IconButton>
      <Menu
        id="language-menu"
        anchorEl={anchorEl}
        anchorOrigin={{
          vertical: "top",
          horizontal: "right"
        }}
        keepMounted
        transformOrigin={{
          vertical: "top",
          horizontal: "left"
        }}
        open={open}
        onClose={onClose}
      >
        <MenuItem onClick={onLanguageChange("ro")}>
          {t("Language.Romanian")}
        </MenuItem>
        <MenuItem onClick={onLanguageChange("en")}>
          {t("Language.English")}
        </MenuItem>
      </Menu>
    </>
  );
};

LanguageComponent.propTypes = {
  languageIsSet: PropTypes.bool.isRequired,
  anchorEl: PropTypes.object,
  onMenuOpen: PropTypes.func.isRequired,
  onLanguageChange: PropTypes.func.isRequired,
  onClose: PropTypes.func.isRequired,
  flag: PropTypes.object.isRequired,
  flagsPath: PropTypes.string.isRequired
};

export default LanguageComponent;
