import React, { useState, useEffect } from "react";
import { useTranslation } from "react-i18next";
import LanguageComponent from "./LanguageComponent";

const flagsPath = process.env.PUBLIC_URL
  ? `${process.env.PUBLIC_URL}/flags`
  : "flags";

const LanguageContainer = () => {
  const [anchorEl, setAnchorEl] = useState(null);

  const { i18n } = useTranslation();
  const [flag, setFlag] = useState({
    name: "RO",
    alt: "-"
  });

  useEffect(() => {
    if (!i18n.language) return;
    setFlag({
      name: i18n.language === "en" ? "GB" : i18n.language.toUpperCase(),
      alt: i18n.language
    });
  }, [i18n.language]);

  const handleMenuOpen = event => {
    setAnchorEl(event.currentTarget);
  };

  const handleClose = () => {
    setAnchorEl(null);
  };

  const handleLanguageChange = language => () => {
    if (language !== i18n.language) {
      i18n.changeLanguage(language);
    }
    setAnchorEl(null);
  };

  return (
    <LanguageComponent
      languageIsSet={i18n.language ? true : false}
      anchorEl={anchorEl}
      onMenuOpen={handleMenuOpen}
      onLanguageChange={handleLanguageChange}
      onClose={handleClose}
      flag={flag}
      flagsPath={flagsPath}
    />
  );
};

export default LanguageContainer;
