import React from "react";
import PropTypes from "prop-types";
import {
  Grid,
  List,
  ListItem,
  ListItemText,
  ListItemIcon,
  Link,
  IconButton,
  Tooltip
} from "@material-ui/core";
import UserProfilePicture from "./UserProfilePicture";
import BusinessCenterIcon from "@material-ui/icons/BusinessCenter";
import { FileCopyOutlined } from "@material-ui/icons";
import EmailIcon from "@material-ui/icons/Email";
import { useToast } from "../../../../hooks";
import { useTranslation } from "react-i18next";
import { makeStyles } from "@material-ui/core/styles";
import styles from "../styles";

const useStyles = makeStyles(styles);

const UserProfileCardContent = ({ userData }) => {
  const { email, profilePictureUrl } = userData;
  const { t } = useTranslation();
  const { info } = useToast();
  const classes = useStyles();

  const handleCopyToClipboard = url => () => {
    navigator.clipboard.writeText(url);
    info(t("Generic.CopiedToClipboard"));
  };

  const handleEmailSending = event => {
    window.location.href = `mailto:${email}`;
    event.preventDefault();
  };

  const userName = `${userData.firstName} ${userData.lastName}`;

  return (
    <div className={classes.panel}>
      <UserProfilePicture userData={userData} />
      <Grid container spacing={2}>
        <Grid item xs={12} sm={6}>
          <List>
            <ListItem dense>
              <ListItemIcon>
                <BusinessCenterIcon />
              </ListItemIcon>
              <ListItemText
                primary={
                  <Tooltip title={t("User.Profile.OpenPortfolio")}>
                    <Link href="https://lab.code-rove.com/tsp/" target="_blank">
                      {userName}
                    </Link>
                  </Tooltip>
                }
              />
            </ListItem>
            <ListItem dense>
              <ListItemIcon>
                <EmailIcon />
              </ListItemIcon>
              <ListItemText
                primary={
                  <Tooltip title={t("Generic.SendEmail")}>
                    <Link href="#" onClick={handleEmailSending}>
                      {email}
                    </Link>
                  </Tooltip>
                }
              />
            </ListItem>
            {profilePictureUrl && (
              <ListItem dense>
                <ListItemIcon>
                  <Tooltip title={t("Generic.Copy")}>
                    <IconButton
                      size="small"
                      onClick={handleCopyToClipboard(profilePictureUrl)}
                    >
                      <FileCopyOutlined />
                    </IconButton>
                  </Tooltip>
                </ListItemIcon>
                <ListItemText
                  primary={
                    <Tooltip title={t("Generic.OpenInNewTab")}>
                      <Link href={profilePictureUrl} target="_blank">
                        {profilePictureUrl}
                      </Link>
                    </Tooltip>
                  }
                />
              </ListItem>
            )}
          </List>
        </Grid>
      </Grid>
    </div>
  );
};

UserProfileCardContent.propTypes = {
  userData: PropTypes.object.isRequired
};

export default UserProfileCardContent;
