import React, { useMemo } from "react";
import { useTranslation } from "react-i18next";
import { Card, CardHeader, CardContent } from "@material-ui/core";
import { useTuitioToken } from "@flare/tuitio-client-react";
import { camelizeKeys } from "../../../../utils/camelizeKeys";
import PageTitle from "../../../../components/common/PageTitle";
import UserProfileCardContent from "./UserProfileCardContent";

const UserProfileContainer = () => {
  const { t } = useTranslation();
  const { token } = useTuitioToken();

  const decodedToken = useMemo(() => atob(token), [token]);
  const userData = useMemo(
    () => camelizeKeys(JSON.parse(decodedToken)),
    [decodedToken]
  );

  const userLoginDate = useMemo(
    () =>
      t("DATE_FORMAT", {
        date: { value: userData.createdAt, format: "DD-MM-YYYY HH:mm:ss" }
      }),
    [t, userData.createdAt]
  );

  const userDescription = t("User.Profile.Description", {
    userName: `${userData.firstName} ${userData.lastName}`,
    loginDate: userLoginDate
  });

  return (
    <>
      <PageTitle
        text={t("User.Profile.Hello", { userName: userData.firstName })}
      />
      <Card>
        <CardHeader title={userData.userName} subheader={userDescription} />
        <CardContent>
          <UserProfileCardContent userData={userData} />
        </CardContent>
      </Card>
    </>
  );
};

export default UserProfileContainer;
